==> qtmobility_1.0.1.orig.tar.gz: qt-mobility-opensource-src-1.0.1/src/sensors/qsensorpluginloader.cpp <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Solutions Commercial License Agreement provided
** with the Software or, alternatively, in accordance with the terms
** contained in a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** Please note Third Party Software included with Qt Solutions may impose
** additional restrictions and it is the user's responsibility to ensure
** that they have met the licensing requirements of the GPL, LGPL, or Qt
** Solutions Commercial license and the relevant license of the Third
** Party Software they are using.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#include "qsensorpluginloader_p.h"
#include <QtCore/qcoreapplication.h>
#include <QtCore/qdir.h>
#include <QtCore/qdebug.h>

#include "qsensorplugin.h"
#include "qmobilitypluginsearch.h"

QTM_BEGIN_NAMESPACE

QSensorPluginLoader::QSensorPluginLoader(const char *iid, const QString &location)
    : m_iid(iid)
{
    m_location = location + QLatin1String("/");
    load();
}

QSensorPluginLoader::~QSensorPluginLoader()
{
    Q_FOREACH (QPluginLoader *loader, m_loaders) {
        bool ok = loader->unload();
        if (!ok) qWarning() << "Cannot unload" << loader->fileName();
        delete loader;
    }
}

void QSensorPluginLoader::load()
{
    if (!m_plugins.isEmpty())
        return;

    QStringList plugins;
    plugins = mobilityPlugins(QLatin1String("sensors"));

    /* Now discover the dynamic plugins */
    for (int i=0; i < plugins.count(); i++) {
        QPluginLoader *loader = new QPluginLoader(plugins.at(i));

        QObject *o = loader->instance();
        if (o != 0 && o->qt_metacast(m_iid) != 0) {
            QSensorPluginInterface *p = qobject_cast<QSensorPluginInterface*>(o);
            if (p != 0) {
                m_plugins << p;
                m_loaders << loader;
            } else {
                loader->unload();
                delete loader;
            }

            continue;
        } else {
            qWarning() << "QSensorPluginLoader: Failed to load plugin: " << plugins.at(i) << loader->errorString();
        }
        delete o;
        loader->unload();
        delete loader;
    }
}

QTM_END_NAMESPACE

==> qtmobility_1.1.0.orig.tar.gz: qt-mobility-opensource-src-1.1.0/src/sensors/qsensorpluginloader.cpp <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in 
** accordance with the Qt Commercial License Agreement provided with
** the Software or, alternatively, in accordance with the terms
** contained in a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#include "qsensorpluginloader_p.h"
#include <QtCore/qcoreapplication.h>
#include <QtCore/qdir.h>
#include <QtCore/qdebug.h>

#include "qsensorplugin.h"
#include "qmobilitypluginsearch.h"

QTM_BEGIN_NAMESPACE

QSensorPluginLoader::QSensorPluginLoader(const char *iid, const QString &location)
    : m_iid(iid)
{
    m_location = location + QLatin1String("/");
    load();
}

QSensorPluginLoader::~QSensorPluginLoader()
{
    Q_FOREACH (QPluginLoader *loader, m_loaders) {
        bool ok = loader->unload();
        if (!ok) qWarning() << "Cannot unload" << loader->fileName();
        delete loader;
    }
}

void QSensorPluginLoader::load()
{
    if (!m_plugins.isEmpty())
        return;

    QStringList plugins;
    plugins = mobilityPlugins(QLatin1String("sensors"));

    /* Now discover the dynamic plugins */
    for (int i=0; i < plugins.count(); i++) {
        QPluginLoader *loader = new QPluginLoader(plugins.at(i));

        QObject *o = loader->instance();
        if (o != 0 && o->qt_metacast(m_iid) != 0) {
            QSensorPluginInterface *p = qobject_cast<QSensorPluginInterface*>(o);
            if (p != 0) {
                m_plugins << p;
                m_loaders << loader;
            } else {
                loader->unload();
                delete loader;
            }

            continue;
        } else {
            qWarning() << "QSensorPluginLoader: Failed to load plugin";
            if (o == 0) {
                qWarning() << "Reason: o == 0";
            } else if (o->qt_metacast(m_iid) == 0) {
                qWarning() << "Reason: o->qt_metacast(m_iid) == 0";
            }
            qWarning() << "Plugin:" << plugins.at(i);
            qWarning() << "Error:" << loader->errorString();
        }
        delete o;
        loader->unload();
        delete loader;
    }
}

QTM_END_NAMESPACE
